import { drizzle } from 'drizzle-orm/mysql2';
import mysql from 'mysql2/promise';
import { dbConfig } from '@/config';

import { Logger } from '@/plugins/logger/logger.service';
import * as schema from './schema';
import type { DrizzleDB } from '@/types/drizzle.type';

export let db: DrizzleDB;
/**
 * 创建MySQL连接池
 */
const createConnection = async () => {
    try {
        /** MySQL连接池配置 */
        const connection = mysql.createPool({
            host: dbConfig.host,
            port: dbConfig.port,
            user: dbConfig.user,
            password: dbConfig.password,
            database: dbConfig.database,
            /** 连接池配置 */
            connectionLimit: 10,
            queueLimit: 0,
        });

        Logger.info('MySQL连接池创建成功');
        return connection;
    } catch (error) {
        Logger.error(error as Error);
        throw new Error('MySQL连接池创建失败');
    }
};

/**
 * 创建Drizzle数据库实例
 */
export const createDrizzleDB = async () => {
    try {
        const connection = await createConnection();

        /** Drizzle数据库实例 */
        db = drizzle(connection, {
            schema,
            mode: 'default',
            logger: {
                logQuery: (query, params) => {
                    Logger.debug(
                        `SQL: ${query} - Params: ${JSON.stringify(params)}`,
                    );
                },
            },
        });

        Logger.info('Drizzle ORM 初始化成功');
        return db;
    } catch (error) {
        Logger.error(error as Error);
        throw new Error('Drizzle ORM 初始化失败');
    }
};