/**
 * @file        用户表Schema定义
 * @author      hotok
 * @date        2025-06-29
 * @lastEditor  hotok
 * @lastEditTime 2025-06-29
 * @description 用户表的Drizzle ORM schema定义
 */

import { mysqlTable, int, varchar, timestamp, text, tinyint } from 'drizzle-orm/mysql-core';

/**
 * 用户表
 */
export const users = mysqlTable('users', {
    /** 用户ID，主键，自增 */
    id: int('id').primaryKey().autoincrement(),
    
    /** 用户名，唯一索引 */
    username: varchar('username', { length: 50 }).notNull().unique(),
    
    /** 邮箱，唯一索引 */
    email: varchar('email', { length: 100 }).notNull().unique(),
    
    /** 密码哈希 */
    passwordHash: varchar('password_hash', { length: 255 }).notNull(),
    
    /** 用户昵称 */
    nickname: varchar('nickname', { length: 50 }),
    
    /** 用户头像URL */
    avatar: text('avatar'),
    
    /** 用户状态：0-禁用，1-启用 */
    status: tinyint('status').default(1).notNull(),
    
    /** 创建时间 */
    createdAt: timestamp('created_at').defaultNow().notNull(),
    
    /** 更新时间 */
    updatedAt: timestamp('updated_at').defaultNow().onUpdateNow().notNull(),
});

/** 用户表类型 */
export type User = typeof users.$inferSelect;

/** 插入用户类型 */
export type InsertUser = typeof users.$inferInsert; 